.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-after: <!-- index.rst content start -->


Examples
--------

For more information on how to use SGN, see the following guides and tutorials:

.. toctree::
   :maxdepth: 2
   :caption: Examples:

   examples/index
   examples/trivial
   examples/simple
   examples/simple-json


API Reference
-------------

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   api
